@@ -5,7 +5,7 @@
     const_generics,
     vec_spare_capacity,
     maybe_uninit_uninit_array,
-    maybe_uninit_array_assume_init,
+    maybe_uninit_array_assume_init
 )]
 
 pub mod attribute;
@@ -21,9 +21,8 @@ pub mod derive {
     pub use rust_gl_proc::*;
 }
 
-type GL = web_sys::WebGl2RenderingContext;
+pub type GL = web_sys::WebGl2RenderingContext;
 
 use derive_more::*;
 #[derive(Debug, Display, Error)]
 pub struct NoneError();
-
